function y=decorrIIR(y,Noise)
%input is a signal y with size [length,nchann] and Noise of size
%[filterlength,nchann] wich normally distributed between 0 and 1
%The channels of the noise matrix must be twice the number of y
%channels. The filtering will lead to a sample delay that is twice the
%length of filterlength
% -  Audun Solvang 2006 -
%   Uses the functions POL2CART, CONJ, POLY, FLIPLR, FILTER.
%
% Modified: Torbjrn Ursin, 2007

global operations noS verbosityLevel wb
[lengde,nchann]=size(y);
%the radius of the poles
N1=Noise(:,1:nchann);
%the phase of the poles
N2=Noise(:,nchann+1:2*nchann);
%Ensures that none of the poles will be at the circle of unity. The
%tweakfactor may be varied
N1=N1*0.9;
%The phase of the poles must be in the range -pi to pi
N2=(N2-0.5)*2*pi;
%Generate the radius for the zeros
N11=N1.^-1;

%N is the order of the filter:
[N,nchann]=size(N2);
%Transforms the polar notation of zeros to cartesian notation
[re,im]=pol2cart(N2,N11);
compz=re+j*im;
%filters channel by channel
for jj=1:nchann
    %run the filtering in cascade.
    for ii=1:N
        % creates the complex conjugate 
        medz=[compz(ii,jj);conj(compz(ii,jj))];
        % find the polynomial that corresponds to the filter coefficients
        % of the given zero
        b=poly(medz);
        %find the corresponding filtercoeffiecients for the pole
        a=fliplr(b);
        y(:,jj)=filter(b,a,y(:,jj));
        waitbar(3/operations+.5/operations/nchann*(jj-1)+.5/operations/N*ii,wb,'Manipulating phase...');
    end
if verbosityLevel==2
    figure(2)
    subplot(noS,operations,(jj-1)*operations+4)
    plot(b)
    figure(3)
    subplot(noS,operations,(jj-1)*operations+4)
    plot(y(:,jj))
end
end
